@@ -4,10 +4,10 @@ use warnings;
 use strict;
 use Time::HiRes qw( gettimeofday tv_interval );
 use vars qw/$VERSION/;
-$VERSION = '0.2';
+$VERSION = '0.3';
 
 sub tv_mark_point {
-    my ($c) = @_;
+    my ($c, $timername) = @_;
 
     return unless ($c->debug);
 
@@ -31,7 +31,7 @@ sub tv_mark_point {
     $c->stash->{__tv_interval} = { name => $new_name, line => $new_line, time => [gettimeofday] };
 }
 
-sub clear_marked_point {
+sub tv_clear_marked_point {
     my ($c) = @_;
     
     delete $c->stash->{__tv_interval};
@@ -57,7 +57,7 @@ Catalyst::Plugin::tv_interval - call tv_interval of Time::HiRes to ease profilin
         # CODE { do something }
         $c->tv_mark_point; # print debug log how long this CODE takes
         
-        $c->clear_marked_point; # now it looks like we never call ->tv_mark_point before
+        $c->tv_clear_marked_point; # now it looks like we never call ->tv_mark_point before
         $c->tv_mark_point;
         # CODE { do something else }
         $c->tv_mark_point;
@@ -76,7 +76,7 @@ This module uses the functions of tv_interval and [gettimeofday] in L<Time::HiRe
 
 if this is no 'ponit' before, mark a point and remember the file name, line and the [gettimeofday]. or else, compare the 'point' now with the old 'point' and print debug log.
 
-=head2 clear_marked_point
+=head2 tv_clear_marked_point
 
 clear the old 'point'
 
@@ -88,6 +88,8 @@ clear the old 'point'
 
 =item L<Time::HiRes> - High resolution alarm, sleep, gettimeofday, interval timers
 
+=item Catalyst::Plugin::Timer (in Catalyst trunk) - something the same, but it is NOT working when I develop this module.
+
 =back
 
 =head1 AUTHOR
